Updating bmagic files to be sorcery
authorMartin Read <martin@blackswordsonics.com>
Sun, 22 Sep 2013 15:53:55 +0000 (16:53 +0100)
committerMartin Read <martin@blackswordsonics.com>
Sun, 22 Sep 2013 15:53:55 +0000 (16:53 +0100)
bmagic.c
bmagic.h

index 235c5ec..8486216 100644 (file)
--- a/bmagic.h
+++ b/bmagic.h
@@ -1,6 +1,8 @@
-/* bmagic.h
- * 
- * Copyright 2005 Martin Read
+/*! \file sorcery.h
+ *  \brief Monster sorcery rules
+ */
+
+/* Copyright 2005-2013 Martin Read
  * 
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -24,8 +26,8 @@
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#ifndef BMAGIC_H
-#define BMAGIC_H
+#ifndef SORCERY_H
+#define SORCERY_H
 
 /* XXX DATA TYPES XXX */
 
@@ -50,11 +52,11 @@ enum monspell {
        MS_TELEPORT_ASSAULT,    /* Wizard, Archmage, Master Lich */
 };
 
-extern int use_black_magic(int mon);
+extern int mon_use_sorcery(int mon);
 extern void mon_curses(int mon);
 extern void malignant_aura(void);
 
 #endif
 
-/* bmagic.h */
+/* sorcery.h */
 // vim:cindent
--- a/bmagic.c
+++ b/bmagic.c
@@ -1,4 +1,4 @@
-/*! \file bmagic.c 
+/*! \file sorcery.c 
  *  \brief evil magic used by monsters
  */
 
@@ -30,9 +30,9 @@
 #include "monsters.h"
 #include "combat.h"
 
-/* BLACK MAGIC
+/* SORCERY
  *
* Certain of the denizens of the dungeon have the power to use black magic
  * against the player.
  * 
  * The "ordinary" lich may unleash bolts of necromantic force against
  * The more potent order of demons known as defilers may cast curses against
  * the player, or call down a column of fire to smite him.
  *
* Some forms of black magic may be defended against by wearing the proper
  * armour or putting on a suitable ring; others bypass all such defences to
  * strike the player directly, although some of these can be evaded by those
  * with high enough agility.
  */
 
-int use_black_magic(int mon)
+int mon_use_sorcery(int mon)
 {
     /* Returns zero for no spell selected, -1 for unsupported spell
      * selected, 1 for supported spell selected. */
@@ -113,7 +113,7 @@ int use_black_magic(int mon)
        {
            /* 
             * We lack LOS, but pass the 1-in-40 chance; use
* black magic to relocate us to the player's location.
             */
            to_cast = MS_TELEPORT_ASSAULT;
        }
@@ -138,7 +138,7 @@ int use_black_magic(int mon)
        else if (!zero_die(80))
        {
            /* we lack LOS, but passed the 1-in-80 chance to
* close with the player by means of black magic. */
            to_cast = MS_TELEPORT_ASSAULT;
        }
        break;
@@ -241,7 +241,7 @@ int use_black_magic(int mon)
        else if (!zero_die(40))
        {
            /* we lack LOS, but passed the 1-in-40 chance to
* close with the player by means of black magic. */
            to_cast = MS_TELEPORT_ASSAULT;
        }
        break;
@@ -30,9 +30,9 @@
  *
- * Certain of the denizens of the dungeon have the power to use black magic
+ * Certain of the denizens of the dungeon have the power to use sorcery
  * against the player.
  * 
@@ -30,9 +30,9 @@
  * the player, or call down a column of fire to smite him.
  *
- * Some forms of black magic may be defended against by wearing the proper
+ * Some forms of sorcery may be defended against by wearing the proper
  * armour or putting on a suitable ring; others bypass all such defences to
  * strike the player directly, although some of these can be evaded by those
@@ -113,7 +113,7 @@ int use_black_magic(int mon)
            /* 
             * We lack LOS, but pass the 1-in-40 chance; use
-            * black magic to relocate us to the player's location.
+            * sorcery to relocate us to the player's location.
             */
            to_cast = MS_TELEPORT_ASSAULT;
@@ -138,7 +138,7 @@ int use_black_magic(int mon)
        {
            /* we lack LOS, but passed the 1-in-80 chance to
-            * close with the player by means of black magic. */
+            * close with the player by means of sorcery. */
            to_cast = MS_TELEPORT_ASSAULT;
        }
@@ -241,7 +241,7 @@ int use_black_magic(int mon)
        {
            /* we lack LOS, but passed the 1-in-40 chance to
-            * close with the player by means of black magic. */
+            * close with the player by means of sorcery. */
            to_cast = MS_TELEPORT_ASSAULT;
        }
index c45c321..de5cc12 100644 (file)